@@ -16,7 +16,8 @@ def ret_status(elem):
 def ret_date(elem):
 	ret = {
 		'properties' : elem,
-		'value_start' : None
+		'value_start' : None,
+		'value_end': None
 	}
 	if elem['date'] != None:
 		ret.update({
@@ -70,7 +71,8 @@ def ret_multi_select(elem):
 	ret.update({
 		'value' : []
 	})
-	for select in elem['multi_select']:
+	for select in ret['properties']['multi_select']:
+		del select['id']
 		data = {
 		'color' : select['color'],
 		'name' : select['name']
